@@ -41,6 +41,8 @@
  * contributed to this source file (JFreeChart.java) - for a list of ALL
  * contributors to the project, please see the README.txt file.
  *
+ * $Id: JFreeChart.java,v 1.34.2.17 2007/03/22 10:53:54 mungady Exp $
+ *
  * Changes (from 20-Jun-2001)
  * --------------------------
  * 20-Jun-2001 : Modifications submitted by Andrzej Porebski for legend 
@@ -131,14 +133,6 @@
  * 05-Mar-2007 : Added Sergei Ivanov to the contributor list (DG);
  * 16-Mar-2007 : Modified initial legend border (DG);
  * 22-Mar-2007 : New methods for text anti-aliasing (DG);
- * 16-May-2007 : Fixed argument check in getSubtitle(), copy list in 
- *               get/setSubtitles(), and added new addSubtitle(int, Title) 
- *               method (DG);
- * 05-Jun-2007 : Add change listener to default legend (DG);
- * 04-Dec-2007 : In createBufferedImage() methods, make the default image type
- *               BufferedImage.TYPE_INT_ARGB (thanks to Klaus Rheinwald) (DG);
- * 05-Dec-2007 : Fixed bug 1749124 (not registering as listener with
- *               TextTitle) (DG);
  * 
  */
 
@@ -282,10 +276,7 @@ public class JFreeChart implements Drawable,
     /** The chart title (optional). */
     private TextTitle title;
 
-    /** 
-     * The chart subtitles (zero, one or many).  This field should never be
-     * <code>null</code>.
-     */
+    /** The chart subtitles (zero, one or many). */
     private List subtitles;
 
     /** Draws the visual representation of the data. */
@@ -399,7 +390,6 @@ public class JFreeChart implements Drawable,
             legend.setBackgroundPaint(Color.white);
             legend.setPosition(RectangleEdge.BOTTOM);
             this.subtitles.add(legend);
-            legend.addChangeListener(this);
         }
 
         // add the chart title, if one has been specified...
@@ -571,13 +561,7 @@ public class JFreeChart implements Drawable,
      * @see #getTitle()
      */
     public void setTitle(TextTitle title) {
-        if (this.title != null) {
-            this.title.removeChangeListener(this);
-        }
         this.title = title;
-        if (title != null) {
-            title.addChangeListener(this);
-        }
         fireChartChanged();
     }
 
@@ -675,13 +659,12 @@ public class JFreeChart implements Drawable,
      * @see #setSubtitles(List)
      */
     public List getSubtitles() {
-        return new ArrayList(this.subtitles);
+        return this.subtitles;
     }
 
     /**
      * Sets the title list for the chart (completely replaces any existing 
-     * titles) and sends a {@link ChartChangeEvent} to all registered 
-     * listeners.
+     * titles).
      *
      * @param subtitles  the new list of subtitles (<code>null</code> not 
      *                   permitted).
@@ -692,16 +675,8 @@ public class JFreeChart implements Drawable,
         if (subtitles == null) {
             throw new NullPointerException("Null 'subtitles' argument.");
         }
-        setNotify(false);
-        clearSubtitles();
-        Iterator iterator = subtitles.iterator();
-        while (iterator.hasNext()) {
-            Title t = (Title) iterator.next();
-            if (t != null) {
-                addSubtitle(t);
-            }
-        }
-        setNotify(true);  // this fires a ChartChangeEvent
+        this.subtitles = subtitles;
+        fireChartChanged();
     }
 
     /**
@@ -725,7 +700,7 @@ public class JFreeChart implements Drawable,
      * @see #addSubtitle(Title)
      */
     public Title getSubtitle(int index) {
-        if ((index < 0) || (index >= getSubtitleCount())) {
+        if ((index < 0) || (index == getSubtitleCount())) {
             throw new IllegalArgumentException("Index out of range.");
         }
         return (Title) this.subtitles.get(index);
@@ -748,28 +723,6 @@ public class JFreeChart implements Drawable,
         fireChartChanged();
     }
     
-    /**
-     * Adds a subtitle at a particular position in the subtitle list, and sends
-     * a {@link ChartChangeEvent} to all registered listeners.
-     * 
-     * @param index  the index (in the range 0 to {@link #getSubtitleCount()}).
-     * @param subtitle  the subtitle to add (<code>null</code> not permitted).
-     * 
-     * @since 1.0.6
-     */
-    public void addSubtitle(int index, Title subtitle) {
-        if (index < 0 || index > getSubtitleCount()) {
-            throw new IllegalArgumentException(
-                    "The 'index' argument is out of range.");
-        }
-        if (subtitle == null) {
-            throw new IllegalArgumentException("Null 'subtitle' argument.");
-        }
-        this.subtitles.add(index, subtitle);
-        subtitle.addChangeListener(this);
-        fireChartChanged();
-    }
-    
     /**
      * Clears all subtitles from the chart and sends a {@link ChartChangeEvent}
      * to all registered listeners.
@@ -905,7 +858,7 @@ public class JFreeChart implements Drawable,
      * {@link RenderingHints#VALUE_TEXT_ANTIALIAS_OFF}, then sends a 
      * {@link ChartChangeEvent} to all registered listeners.
      * 
-     * @param flag  the new value of the flag.
+     * @param flag
      * 
      * @since 1.0.5
      * 
@@ -917,7 +870,7 @@ public class JFreeChart implements Drawable,
             setTextAntiAlias(RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
         }
         else {
-            setTextAntiAlias(RenderingHints.VALUE_TEXT_ANTIALIAS_OFF);
+            setTextAntiAlias(RenderingHints.VALUE_TEXT_ANTIALIAS_OFF);            
         }
     }
 
@@ -1230,10 +1183,10 @@ public class JFreeChart implements Drawable,
     /**
      * Creates a rectangle that is aligned to the frame.
      * 
-     * @param dimensions  the dimensions for the rectangle.
-     * @param frame  the frame to align to.
-     * @param hAlign  the horizontal alignment.
-     * @param vAlign  the vertical alignment.
+     * @param dimensions
+     * @param frame
+     * @param hAlign
+     * @param vAlign
      * 
      * @return A rectangle.
      */
@@ -1373,7 +1326,7 @@ public class JFreeChart implements Drawable,
      */
     public BufferedImage createBufferedImage(int width, int height, 
                                              ChartRenderingInfo info) {
-        return createBufferedImage(width, height, BufferedImage.TYPE_INT_ARGB,
+        return createBufferedImage(width, height, BufferedImage.TYPE_INT_RGB, 
                 info);
     }
 
@@ -1419,7 +1372,7 @@ public class JFreeChart implements Drawable,
                                              ChartRenderingInfo info) {
 
         BufferedImage image = new BufferedImage(imageWidth, imageHeight, 
-                BufferedImage.TYPE_INT_ARGB);
+                BufferedImage.TYPE_INT_RGB);
         Graphics2D g2 = image.createGraphics();
         double scaleX = imageWidth / drawWidth;
         double scaleY = imageHeight / drawHeight;
@@ -1737,7 +1690,7 @@ class JFreeChartInfo extends ProjectInfo {
 
         // get a locale-specific resource bundle...
         String baseResourceClass 
-                = "org.jfree.chart.resources.JFreeChartResources";
+            = "org.jfree.chart.resources.JFreeChartResources";
         ResourceBundle resources = ResourceBundle.getBundle(baseResourceClass);
 
         setName(resources.getString("project.name"));
@@ -1751,16 +1704,14 @@ class JFreeChartInfo extends ProjectInfo {
         setContributors(Arrays.asList(
             new Contributor[]{
                 new Contributor("Eric Alexander", "-"),
-                new Contributor("Richard Atkinson", 
-                        "richard_c_atkinson@ntlworld.com"),
+                new Contributor(
+                    "Richard Atkinson", "richard_c_atkinson@ntlworld.com"
+                ),
                 new Contributor("David Basten", "-"),
                 new Contributor("David Berry", "-"),
-                new Contributor("Chris Boek", "-"),
-                new Contributor("Zoheb Borbora", "-"),
                 new Contributor("Anthony Boulestreau", "-"),
                 new Contributor("Jeremy Bowman", "-"),
                 new Contributor("Nicolas Brodu", "-"),
-                new Contributor("Jody Brownell", "-"),
                 new Contributor("David Browning", "-"),
                 new Contributor("Soren Caspersen", "-"),
                 new Contributor("Chuanhao Chiu", "-"),
@@ -1770,7 +1721,6 @@ class JFreeChartInfo extends ProjectInfo {
                 new Contributor("Paolo Cova", "-"),
                 new Contributor("Mike Duffy", "-"),
                 new Contributor("Don Elliott", "-"),
-                new Contributor("David Forslund", "-"),
                 new Contributor("Jonathan Gabbai", "-"),
                 new Contributor("David Gilbert", 
                         "david.gilbert@object-refinery.com"),
@@ -1804,8 +1754,8 @@ class JFreeChartInfo extends ProjectInfo {
                 new Contributor("David M. O'Donnell", "-"),
                 new Contributor("Krzysztof Paz", "-"),
                 new Contributor("Tomer Peretz", "-"),
-                new Contributor("Xavier Poinsard", "-"),
                 new Contributor("Andrzej Porebski", "-"),
+                new Contributor("Xavier Poinsard", "-"),
                 new Contributor("Viktor Rajewski", "-"),
                 new Contributor("Eduardo Ramalho", "-"),
                 new Contributor("Michael Rauch", "-"),
@@ -1829,7 +1779,6 @@ class JFreeChartInfo extends ProjectInfo {
                 new Contributor("Daniel van Enckevort", "-"),
                 new Contributor("Laurence Vanhelsuwe", "-"),
                 new Contributor("Sylvain Vieujot", "-"),
-                new Contributor("Jelai Wang", "-"),
                 new Contributor("Mark Watson", "www.markwatson.com"),
                 new Contributor("Alex Weber", "-"),
                 new Contributor("Matthew Wright", "-"),
